# This file is automatically generated. Please do not modify.

from . import AsciiArt

fedora_sericea = AsciiArt(match=r'''"Fedora Sericea"* | "Sericea"*''', color='12 7', ascii=r"""
${c1}              :oooo,  .','
      .';;;.;oooooooolooooo'
     coooooooooooooooooooooooolc'
  .':oooooooooooo${c2}ll${c1}ooooooooooooool
.oooooooooooooooo${c2}ll${c1}oooooooooooo${c2}l${c1}ool
ooooooooooooooooo${c2}ll${c1}ooooooooooo${c2}ll${c1}oo'
 oooo${c2}l${c1}oooooooooo${c2}lll${c1}ooooooooo${c2}lll${c1}oo
 .ooooo${c2}lll${c1}ooooo${c2}lll${c1}ooooooooo${c2}lll${c1}ool
 .ooooooo${c2}lll${c1}oo${c2}llll${c1}oooo${c2}lllll${c1}ooooo:
  'oooooooo${c2}llllllllllll${c1}oooooooo'
     .c,.oo${c2}lllll${c1}oooooooo.${c2}
           'll;
           'll.
           lll
           lll
          ;ll,
          .l:
""")
    