# This file is automatically generated. Please do not modify.

from . import AsciiArt

haiku = AsciiArt(match=r'''"Haiku"*''', color='1 3 7 2', ascii=r'''
${c3}

           MMMM              MMMM
           MMMM              MMMM
           MMMM              MMMM
           MMMM              MMMM
           MMMM${c4}       .ciO| /YMMMMM*"
${c3}           MMMM${c4}   .cOMMMMM|/MMMMM/`
 ,         ,iMM|/MMMMMMMMMMMMMMM*
  `*.__,-cMMMMMMMMMMMMMMMMM/`${c3}.MMM
           MM${c4}MMMMMMM/`:MMM/  ${c3}MMMM
           MMMM              MMMM
           MMMM              MMMM
           """"              """"
''')
    