# This file is automatically generated. Please do not modify.

from . import AsciiArt

void_small = AsciiArt(match=r'''"void_small"''', color='2 8', ascii=r"""
${c1}    _______
 _ \______ -
| \  ___  \ |
| | /   \ | |
| | \___/ | |
| \______ \_|
 -_______\
""")
    