# This file is automatically generated. Please do not modify.

from . import AsciiArt

panwah = AsciiArt(match=r'''"Panwah"*''', color='7 1 0', ascii=r"""
${c1}
          HHH
         HAAAH                             HHH
         HAAAAH                           HAAAH
        HAAAAAAH                         HAAAAH
        HAAAAAAH                       HAAAAAH
       HAAAAAAAAH${c2}WWWWWWWWWWWWWWWW      ${c1}HAAAAAH$
       HAAAAAAAAH${c2}WWWWWWWWWWWWWWWWWWWW${c1} HAAAAAH
       HAA${c2}WWWWWWWWWWWWWWWWWWWWWWWWWWWWW${c1}AAAAAH${c2}
      WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW${c1}WAH${c2}
     WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW
   WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW
  WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW
 WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW
 WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW
 WWWWWWW${c1}AAA${c2}WWWW   WWWWWWWWWWWWWWWWWWWWWWWWWWW
   WWWW${c1}AAA${c2}WWWWW    WWWWWWW    WWWWWWWWWWWWWWW
    WW${c1}AAA${c2}WWWWWWWWWWWWWWWWW   WWWWW${c1}AAA${c2}WWWWWWWW
     ${c1}AAA${c2}WWWWW${c1}OOOOOOOOOOO${C2}WWWWWWWWWWW${c1}AAA${c2}WWWWWW
           ${c1}OOOO${c3}GGGGGGG${c1}OOOO${c2}WWWWWWWWWW${c1}AAA${c2}WWWW
            ${c1}OOO${c3}GGGGGGG${c1}OOO${c2}WWWWWWWWWWWW${c1}AAA${c2}W
              ${c1}OOOOOOOOO
""")
    