# This file is automatically generated. Please do not modify.

from . import AsciiArt

slackel = AsciiArt(match=r'''"Slackel"*''', color='3', ascii=r'''
${c1}              _aawmmmmmwwaaaaas,,,_.
           .ammmmm###mmmmmmm###BQmm##mws
         .am###mmBmBmBmBmBmBmmmmm#mmmm#2
        <q###mmBmBmBmBmBmBmBmBmBmBmmBmZ`
       um#mmmBmBm##U##mmBmBmBmWmmBmWm#(
     .wm#mmBBmm#Y~   ~XmBmBmWmmmmmBm#e
    .dm#mmWmm#Z'      ]#mBmBmmBZ!""""`
   .dm#mmBmm#2`       ]mmmBmBm#2
   jm#mmWmm#2`        dmmBmBmB#(
  )m##mBmmWZ`        )##mBmBmmZ
 :dmmmBmBm#'        .d#mBmBmWZ(
 j#mmBmBmme         jmmmBmBm#2
_m#mBmWmmm'        )mmmBmBmmZ`
]##mBmmm#2        <m#mBmBmB#^
dmmmBmWm#C       <m#mBmBmB#(
ZmmBmBmmmh.    _jm#mmBmBm#(
XBmBmBmBmm6s_aum##mmBmBm&^
3$mBmBmBmmm#mmmmmmBmBm#2'
+ZmBmBmWmBmBmWmmBmBm##!
 )ZmBmBmmmBmBmmBmB##!`
  -4U#mBmWmBmBm##2"
    -!!XU##US*?"-
''')
    