# This file is automatically generated. Please do not modify.

from . import AsciiArt

elementary_small = AsciiArt(match=r'''"elementary_small"*''', color='4 7 1', ascii=r"""
${c2}  _______
 / ____  \
/  |  /  /\
|__\ /  / |
\   /__/  /
 \_______/
""")
    