# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse_tumbleweed = AsciiArt(match=r'''"openSUSE Tumbleweed"* | "openSUSE_Tumbleweed"*''', color='2 7', ascii=r"""
${c2}         JJJJJJJJ
      JJJJJJJJJJJJJJ
    JJJJJJ   =JJJJJJJ
   JJJJ      =JJJ JJJJ
   JJJ       =JJJ   JJJ
  JJJJ       =JJJ   JJJ
  JJJJJJJJJJJJJJJ   JJJJ
   JJJJJJJJJJJJJJ   JJJJ
   JJJJ             JJJJ
    JJJJJ=          JJJJ
      JJJJJJJJJJJJJJJJJJJJJJJJJJJJJ=
        =JJJJJJJJJJJJJJJJJJJJJJJJJJJJJ
                    JJJJ         =JJJJJJ
                    JJJJ            =JJJJ
                    JJJJ   JJJJJJJJJJJJJJ
                    JJJJ   JJJJJJJJJJJJJJJ
                    JJJJ   JJJJ       JJJJ
                     JJJ   JJJJ       JJJ
                     JJJJJ JJJJ      JJJJ
                      =JJJJJJJJ   JJJJJJ
                        JJJJJJJJJJJJJJ
                           JJJJJJJ=
""")
    