# This file is automatically generated. Please do not modify.

from . import AsciiArt

celos = AsciiArt(match=r'''"CelOS"*''', color='4 6 0 5', ascii=r"""

${c4}                     .,cmmmmmmmmmmmc,.
                .,cmMMMMMMMMMMMMMMMMMMMMmc.
             .cMMMMMMMMMMMMMMMMMMMMMMMMMMMmc.
           .cMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMc.
         ,:MMM ${c3}####################################${c4}
        cMMMMMMmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmc.
       .MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM.
      .MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMc
      "******************************MMMMMMMMMMMMMc:
${c3}#################################### ${c4}MMMMMMMMMMMMMc
      "MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM:
       "MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM"
       'MMMMMMMMM*******************************:
        \"MMMMMM ${c3}#####################################
         ${c4}`:MMMMMMmmmmmmmmmmmmmmmmmmmmmmmmmmmmm;
           `"MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM"
             `":MMMMMMMMMMMMMMMMMMMMMMMMM;'
                `":MMMMMMMMMMMMMMMMMMM:"
                     "************"
""")
    