# This file is automatically generated. Please do not modify.

from . import AsciiArt

arch_small = AsciiArt(match=r'''"arch_small"''', color='6 7 1', ascii=r"""
${c1}      /\
     /  \
    /\   \
${c2}   /      \
  /   ,,   \
 /   |  |  -\
/_-''    ''-_\
""")
    