# This file is automatically generated. Please do not modify.

from . import AsciiArt

haiku_small = AsciiArt(match=r'''"haiku_small"*''', color='2 8', ascii=r"""
${c1}       ,^,
      /   \
*--_ ;     ; _--*
\   '"     "'   /
 '.           .'
.-'"         "'-.
 '-.__.   .__.-'
       |_|
""")
    