# This file is automatically generated. Please do not modify.

from . import AsciiArt

libreelec = AsciiArt(match=r'''"LibreELEC"*''', color='2 3 7 14 13', ascii=r"""
${c1}          :+ooo/.      ${c2}./ooo+:
${c1}        :+ooooooo/.  ${c2}./ooooooo+:
${c1}      :+ooooooooooo:${c2}:ooooooooooo+:
${c1}    :+ooooooooooo+-  ${c2}-+ooooooooooo+:
${c1}  :+ooooooooooo+-  ${c3}--  ${c2}-+ooooooooooo+:
${c1}.+ooooooooooo+-  ${c3}:+oo+:  ${c2}-+ooooooooooo+-
${c1}-+ooooooooo+-  ${c3}:+oooooo+:  ${c2}-+oooooooooo-
${c1}  :+ooooo+-  ${c3}:+oooooooooo+:  ${c2}-+oooooo:
${c1}    :+o+-  ${c3}:+oooooooooooooo+:  ${c2}-+oo:
${c4}     ./   ${c3}:oooooooooooooooooo:   ${c5}/.
${c4}   ./oo+:  ${c3}-+oooooooooooooo+-  ${c5}:+oo/.
${c4} ./oooooo+:  ${c3}-+oooooooooo+-  ${c5}:+oooooo/.
${c4}-oooooooooo+:  ${c3}-+oooooo+-  ${c5}:+oooooooooo-
${c4}.+ooooooooooo+:  ${c3}-+oo+-  ${c5}:+ooooooooooo+.
${c4}  -+ooooooooooo+:  ${c3}..  ${c5}:+ooooooooooo+-
${c4}    -+ooooooooooo+:  ${c5}:+ooooooooooo+-
${c4}      -+oooooooooo+:${c5}:+oooooooooo+-
${c4}        -+oooooo+:    ${c5}:+oooooo+-
${c4}          -+oo+:        ${c5}:+oo+-
${c4}            ..            ${c5}..
""")
    