# This file is automatically generated. Please do not modify.

from . import AsciiArt

alpine_small = AsciiArt(match=r'''"alpine_small"''', color='4 7', ascii=r"""
${c1}   /\ /\
  /${c2}/ ${c1}\  \
 /${c2}/   ${c1}\  \
/${c2}//    ${c1}\  \
${c2}//      ${c1}\  \
         \
""")
    