# This file is automatically generated. Please do not modify.

from . import AsciiArt

slackware_small = AsciiArt(match=r'''"slackware_small"*''', color='4 7 1', ascii=r"""
${c1}   ________
  /  ______|
  | |______
  \______  \
   ______| |
| |________/
|____________
""")
    