# This file is automatically generated. Please do not modify.

from . import AsciiArt

biglinux = AsciiArt(match=r'''"BigLinux"*''', color='6 11 4', ascii=r"""
${c1}                                 ...
                              :OWMMMNd.
                            :NMMMMMMMMWc
                  okkl.    kMMMMMW0xdOWMl
  :             xMMMMMW.  kMMMMNc      lW.
 :x             NMMMMMO  ,MMMM0.        'l
 Xx              "lkk"   kMMMX      .okx,
${c2}.MX      .cc;.    .xXKx. KMMM:    .OMMMMMl
:MM'   'KMMMMWK:  0MMMMk xMMM.   lWMMMMMMM'
cMMN:;xMMMMk::MMO oMMMMX .XMM. .KMMMWOOMMMd
'MMMMMMMMN,   NMMx OMMMMl .kM0OMMMMk.  ;MMd
 xMMMMMMd    .MMMW  :NMMMd  .ckKKx'     KMc
  dWMNd.     oMMMN    lkNMX,            oM.
 ;.         ;MMMMx      "MM:.           cO
${c3} .X.       oMMMMW.                      l.
  dMk:..;xWMMMMW,
   kMMMMMMMMMMX.
    :XMMMMMMK:
      ':MM:"      Made in Brazil
""")
    