# This file is automatically generated. Please do not modify.

from . import AsciiArt

sailfish = AsciiArt(match=r'''"Sailfish"*''', color='4 5 7 6', ascii=r"""
${c1}                 _a@b
              _#b (b
            _@@   @_         _,
          _#^@ _#*^^*gg,aa@^^
          #- @@^  _a@^^
          @_  *g#b
          ^@_   ^@_
            ^@_   @
             @(b (b
            #b(b#^
          _@_#@^
       _a@a*^
   ,a@*^
""")
    