# This file is automatically generated. Please do not modify.

from . import AsciiArt

openeuler = AsciiArt(match=r'''"openEuler"*''', color='4 7 1', ascii=r"""
${c1}                 `.cc.`
             ``.cccccccc..`
          `.cccccccccccccccc.`
      ``.cccccccccccccccccccccc.``
   `..cccccccccccccccccccccccccccc..`
`.ccccccccccccccc${c2}/++/${c1}ccccccccccccccccc.`
.ccccccccccccccc${c2}mNMMNdo+oso+${c1}ccccccccccc.
.cccccccccc${c2}/++odms+//+mMMMMm/:+syso/${c1}cccc
.ccccccccc${c2}yNNMMMs:::/::+o+/:${c1}c${c2}dMMMMMm${c1}cccc
.ccccccc${c2}:+NmdyyhNNmNNNd:${c1}ccccc${c1}${c2}:oyyyo:${c1}cccc
.ccc${c2}:ohdmMs:${c1}cccc${c2}+mNMNmy${c1}ccccccccccccccccc
.cc${c2}/NMMMMMo////:${c1}c${c2}:///:${c1}cccccccccccccccccc
.cc${c2}:syysyNMNNNMNy${c1}ccccccccccccccccccccccc
.cccccccc${c2}+MMMMMNy${c1}c${c2}:/+++/${c1}cccccccccccccccc
.ccccccccc${c2}ohhhs/${c1}c${c2}omMMMMNh${c1}ccccccccccccccc
.ccccccccccccccc${c2}:MMMMMMMM/${c1}cccccccccccccc
.cccccccccccccccc${c2}sNNNNNd+${c1}cccccccccccccc.
`..cccccccccccccccc${c2}/+/:${c1}cccccccccccccc..`
   ``.cccccccccccccccccccccccccccc.``
       `.cccccccccccccccccccccc.`
          ``.cccccccccccccc.``
              `.cccccccc.`
                 `....`
""")
    