# This file is automatically generated. Please do not modify.

from . import AsciiArt

cleanjaro_small = AsciiArt(match=r'''"cleanjaro_small"*''', color='7 7', ascii=r"""
${c1}█████ ██████████
█████ ██████████
█████
█████
█████
████████████████
████████████████
""")
    