# This file is automatically generated. Please do not modify.

from . import AsciiArt

openbsd_small = AsciiArt(match=r'''"openbsd_small"''', color='3 7 6 1 8', ascii=r"""
${c1}      _____
    \-     -/
 \_/         \
 |        ${c2}O O${c1} |
 |_  <   )  3 )
 / \         /
    /-_____-\
""")
    