# This file is automatically generated. Please do not modify.

from . import AsciiArt

nixos_small = AsciiArt(match=r'''"nixos_small"''', color='4 6', ascii=r"""
${c1}  \\  \\ //
 ==\\__\\/ //
   //   \\//
==//     //==
 //\\___//
// /\\  \\==
  // \\  \\
""")
    