# This file is automatically generated. Please do not modify.

from . import AsciiArt

furreto = AsciiArt(match=r'''"Furreto"*''', color='211 255 225 199', ascii=r"""
${c1}
               ${c1}.xOOko      .odd,
              o${c3}X${c2}WWK${c3}O${c1}OOO. 'O${c3}N${c2}WW${c3}0${c1}kkk.
             .k0${c3}XKO${c1}OOOOOcOO${c2}NWN${c1}OOOOO.
              xOOOOOOOOOkkOOOOOOOOO;
       .O0OkkocxO000000kcdk0OO0OOkx
       k${c3}W${c2}MX${c1}kkkkloxkkkx;  :dxxxxddc...
      'kO0OOOOOkc          .cl:..kk0KK0Okc
      ;kOOO0000xd.  dO00000Oo  .xkO${c3}N${c2}MM${c3}X${c1}OOOO
    .dddxkOOOkddc.k${c3}K${c2}NWW${c3}N${c1}000000l.ddk${c2}00${c1}00OOOO.
     'dd:;ddddd;.d${c3}K${c2}MMM${c3}W${c1}K00KKK0O::ddxkO00Oko
             .okxkOKK0kkOO00KKOxxlodddddddl
           .00OOkkkkkkkkOOO00OOOO0O;  .dddl
          'kkkkkxxkkkkkkkOOkxdxkxxddd.
          cddddddddxxkkkkk${c4}xddddddddddo
          'ddddddodddddddddddddddddddc
           .ddddddodddddddddodddddddc
                    .odddo.

                   .kOOkkk;
                  lkKWNkkkxc
                 kkxkkkkkkx.
                  ,,..xxx.
""")
    