# This file is automatically generated. Please do not modify.

from . import AsciiArt

ultramarine_linux = AsciiArt(match=r'''"Ultramarine Linux"* | "ultramarine"*''', color='4 7', ascii=r"""
${c1}            .cd0NNNNNNNXOdc.
        .:xKNNNNNNNNNNNNNNNNKd;.
      ,dXNNNNNNNNNNNNNNNNNNNNNNNd,
    'ONNNNNNNNNNNNNNNNNNNNNNNNNNNNO'
  .xNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNk.
 .0NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN0.
.0NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN0.
dNNNNNNNNNNNNWWWWWWWWNNNNNNNNNNNNNNNNNNd
NNNNNNNNNNNNNW${c2}MMMMMMMM${c1}WWNNNNNNNNNNNNNNNN
NNNNNNNNNNNNNNW${c2}MMMMMMMMM${c1}WWNNNNNNNNNNNNNN
NNNNNNNNNNNNNNW${c2}MMMMMMMMMMMM${c1}WNNNNNNNNNNNN
NNNNNNNNNNWWW${c2}MMMMMMMMMMMMMMMM${c1}WWWNNNNNNNX
oNWWWW${c2}MMMMMMMMMMMMMMMMMMMMMMMMMMMM${c1}WWWNNo
 OW${c2}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM${c1}WO
 .OW${c2}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM${c1}WO.
   lNW${c2}MMMMMMMMMMMMMMMMMMMMMMMMMMMM${c1}WNl
    .dNW${c2}MMMMMMMMMMMMMMMMMMMMMMMM${c1}WNd.
      .cKW${c2}MMMMMMMMMMMMMMMMMMMM${c1}WKc.
         'oOXWWW${c2}MMMMMMMM${c1}WWWXOl.
             ;lkXNNNNNNXkl'
""")
    