# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse_small = AsciiArt(match=r'''"opensuse_small" | "suse_small"*''', color='2 7', ascii=r"""
${c1}  _______
__|   __ \
     / .\ \
     \__/ |
   _______|
   \_______
__________/
""")
    