# This file is automatically generated. Please do not modify.

from . import AsciiArt

fedora_small = AsciiArt(match=r'''"fedora_small"''', color='12', ascii=r"""
${c1}        ,'''''.
       |   ,.  |
       |  |  '_'
  ,....|  |..
.'  ,_;|   ..'
|  |   |  |
|  ',_,'  |
 '.     ,'
   '''''
""")
    