# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu_small = AsciiArt(match=r'''"ubuntu_small"''', color='1', ascii=r"""
${c1}       ..;,; .,;,.
    .,lool: .ooooo,
   ;oo;:    .coool.
 ....         ''' ,l;
:oooo,            'oo.
looooc            :oo'
 '::'             ,oo:
   ,.,       .... co,
    lo:;.   :oooo; .
     ':ooo; cooooc
        '''  ''''
""")
    