# This file is automatically generated. Please do not modify.

from . import AsciiArt

shastraos = AsciiArt(match=r'''"ShastraOS"*''', color='6', ascii=r"""
${c1}                          ..,;;,'.
                       ':oo.     ;o:
                     :o,           ol
                   .oo        ..';co:
                   ooo',;:looo;
               .;lddl
             cx   .xl     .c:'
            dd     xx     xx ,d;
           .xd     cx.    xx   dd.
            cx:    .xo    xx    ,x:
             'xl    xx    cx'    .xl
               xd,  xx    .xd     dx.
                .xo:xx     xx    .xx
                   'c      xx:.'lx:
                      ..,;cxxxo
             .';:codxxl   lxo
           cd.           'xo
           :o,         'ld
            .oc'...';lo
""")
    