# This file is automatically generated. Please do not modify.

from . import AsciiArt

salix = AsciiArt(match=r'''"Salix"*''', color='2', ascii=r'''
${c1}              __s_aaaaaaaaauuoXSSSSSSSS:
          ._xSSSSSSSSSSSSSSSSSSSSSSSSSS:
        _aSSSSSSSSSSSSSSSSSSSSSSSSSSSSS:
      _xSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS:
     <XSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS:
    -"^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^'

  .ssssssssssssssssssssssssssssssssssss
  {SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSl
  oSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS;
 :XSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS;
 {SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
 -"""""""""""""""""""""""""""""""""""'

 <assssssssssssssssssssssssssssssss>
 nSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS}
 nSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS}`
 XSSSSSSSSSSSSSSSSSSSSSSSSSSSS"`
 SSSSSSSSSSSSSSSSSSSSSSSSS!"`
-""""""""""""""""""""""`
''')
    