# This file is automatically generated. Please do not modify.

from . import AsciiArt

univalent = AsciiArt(match=r'''"Univalent"*''', color='6 6', ascii=r"""
${c1}
   UUUUUUU                   UUUUUUU
   UUUUUUU                   UUUUUUU
   UUUUUUU         A         UUUUUUU
   UUUUUUU        A|A        UUUUUUU
   UUUUUUU       A | A       UUUUUUU
   UUUUUUU      A  |  A      UUUUUUU
   UUUUUUU     A|  |  |A     UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
   UUUUUUU    A |  |  | A    UUUUUUU
    UUUUUUU   A |  |  | A   UUUUUUU
     UUUUUUU  A |  |  | A  UUUUUUU
       UUUUUUUAAAAAAAAAAAUUUUUUU
          UUUUUUUUUUUUUUUUUUU
             UUUUUUUUUUUUU
""")
    