# This file is automatically generated. Please do not modify.

from . import AsciiArt

aosc_os = AsciiArt(match=r'''"AOSC OS"*''', color='4 0 1 3', ascii=r'''
${c2}                  __
               ${c2}gpBBBBBBBBBP
           ${c2}_gBBBBBBBBBRP
         ${c2}4BBBBBBBBRP  ${c4},_____
              ${c2}`"" ${c4}_g@@@@@@@@@@@@@%g>
              ${c4}__@@@@@@@@@@@@@@@@P"  ${c1}___
           ${c4}_g@@@@@@@@@@@@@@@N"` ${c1}_gN@@@@@N^
       ${c4}_w@@@@@@@@@@@@@@@@P" ${c1}_g@@@@@@@P"
    ${c4}_g@@@@@@@@@@@@@@@N"`  ${c1}VMNN@NNNM^`
  ${c4}^MMM@@@@@@@@@@@MP" ${c3},ggppww__
          ${c4}`""""" ${c3}_wNNNNNNNNNNNNNNNNNNN
              ${c3}_gBNNNNNNNNNNNNNNNNNP"
          ${c3}_wNNNNNNNNNNNNNNNNNNMP`
       ${c3}_gBNNNNNNNNNNNNNNNNNP"
   ${c3}_wNNNNNNNNNNNNNNNNNNNM^
   ${c3}""Y^^MNNNNNNNNNNNNP`
           ${c3}`"""""""
''')
    