# This file is automatically generated. Please do not modify.

from . import AsciiArt

cutefishos = AsciiArt(match=r'''"CutefishOS"*''', color='6 7 4', ascii=r"""
${c1}                     ___ww___
_              _wwMMM@M^^^^MMMMww_
M0w_       _wMMM~~             ~~MMm_
  ~MMy _ww0M~                      ~MMy
    ~MMMM~                      o    "MM
${c3}  jw0M~~MMMw_                      _wMM'
wMM~      ~~MMmw__             __w0M~
~             ~~MM0MmwwwwwwwwwMMM~
                    ~~~~^^~~~
""")
    