# This file is automatically generated. Please do not modify.

from . import AsciiArt

gentoo_small = AsciiArt(match=r'''"gentoo_small"''', color='5 7', ascii=r"""
${c1} _-----_
(       \
\    0   \
${c2} \        )
 /      _/
(     _-
\____-
""")
    