# This file is automatically generated. Please do not modify.

from . import AsciiArt

postmarketos_small = AsciiArt(match=r'''"postmarketos_small"''', color='2 7', ascii=r"""
${c1}        /\
       /  \
      /    \
      \__   \
    /\__ \  _\
   /   /  \/ __
  /   / ____/  \
 /    \ \       \
/_____/ /________\
""")
    