# This file is automatically generated. Please do not modify.

from . import AsciiArt

garuda_small = AsciiArt(match=r'''"garuda_small"''', color='7 7 3 7 2 4', ascii=r"""
${c3}     .----.
   .'   ${c6},${c3}  '.
${c4} .'    ${c6}'${c3}-----|
'${c5}.   -----,
  '.____.'
""")
    