# This file is automatically generated. Please do not modify.

from . import AsciiArt

raspbian_small = AsciiArt(match=r'''"Raspbian_small"*''', color='2 1', ascii=r"""
${c1}   ..    ,.
  :oo: .:oo:
  'o\o o/o:
${c2} :: . :: . ::
:: :::  ::: ::
:'  '',.''  ':
 ::: :::: :::
 ':,  ''  ,:'
   ' ~::~ '
""")
    