# This file is automatically generated. Please do not modify.

from . import AsciiArt

mx_small = AsciiArt(match=r'''"mx_small"*''', color='4 6 7', ascii=r"""
${c3}    \\  /
     \\/
      \\
   /\/ \\
  /  \  /\
 /    \/  \
/__________\
""")
    