# This file is automatically generated. Please do not modify.

from . import AsciiArt

yiffos = AsciiArt(match=r'''"yiffOS"*''', color='93 92', ascii=r"""
${c1}            NK
             NxKXW
             WOlcoXW
             0olccloxNW
             XxllllllloxOKNW
             Nklllllllllllodk0XWW
            N0dllllllllllllllodxOKNW
          WKxlllllllllllllllllllooxOKN
        WKdllllllllllllllooooooooooooo
       Nxllllllllllllllloooooooooo${c2}oooo
${c1}     XXNOolllllllllllloooooooooo${c2}oooooo
${c1}   WX0xolllllllllllooooooooooo${c2}oooooooo
${c1} XWN0xolllllllllloooooooo${c2}ooooooooooooo
${c1}   Kkdolllllllooooddddd${c2}doooooooooooddo
${c1}        K00XNW${c2}      WX0xdooooooddddddd
                       WXOxdoooooodddd
                          WXOxdddddddd
                                NX0ddd
                                  WN0d
""")
    