# This file is automatically generated. Please do not modify.

from . import AsciiArt

evolutionos = AsciiArt(match=r'''"EvolutionOS"*''', color='4 7', ascii=r"""
${c1}\e[1;32m      dddddddddddddddddddddddd
  .dddd''''''''''''''''''''''dddd.
  dd:   dddddddddddddddddddd;   dd:
  dd:   ldl:''''''''''''''''    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl: ddddddd;  ddddd;   dd:
  dd:   ldl: '''''''   '''''    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl:                    dd:
  dd:   ldl: ddddddddddddddd;   dd:
  dddd:.'''  '''''''''''''''  dddd:
     dddddddddddddddddddddddddd;;'
      '''''''''''''''''''''''''\e[0m
""")
    