# This file is automatically generated. Please do not modify.

from . import AsciiArt

openkylin = AsciiArt(match=r'''"openKylin"*''', color='2 7', ascii=r"""
${c1}
             /KKK]
            KKKKKKK`   ]KKKK\
           KKKKK/  /KKKKKKKKK\
          KKKK/ ,KKKKKKKKKKKK^
  ,]KKK  =KKK` /KKKKKKOOOOOO`
,KKKKKK  =KK  /`    [\OOOOOOO\
 \KKKKK  =K            ,OOOOOOO`
 ,KKKKK  =^              \OOOOOO
  ,KKKK   ^               OOOOOO^
   *KKK^                  =OOOOO^
    OOKK^                 OOOOOO^
    \OOOK\               /OOOOOO`
     OOOOOO]           ,OOOOOOO^
     ,OOOOOOOO\]   ,[OOOOOOOOO/
       \OOOOOOOOOOOOOOOOOOOOO`
         [OOOOOOOOOOOOOOOO/`
            ,[OOOOOOOOO]
""")
    