# This file is automatically generated. Please do not modify.

from . import AsciiArt

archcraft_ascii = AsciiArt(match=r'''"archcraft_ascii"*''', color='6 1 2 3 4 5', ascii=r"""
${c1}                   -o\
                  :ooo:
                 .ooooo.
                 ooooooo.
                +oooooooo.
               -oooooooooo.
              --:-+oooooooo.
             yooo+=+sooooooo.
            yoooooosooooooooo.
           y+ooooooooooooooooo.
          yoooooooooooooooooooo`
         yoooooo+oo=  :oo++ooooo`
        :oooooo.           +ooooo-
       -ooooooo.   .::.    +ooosoo=
      -oooooo`    .oooo`     +os-=o=
     =ooooooo=:    `oo+    :=ooo=--`.
    +ooooooooos.          .=sooooooo+-
  .+osossos+-`              `-+osososs+.
 :sss+=-:`                     `:-=+ssss:
:=-:`                                `-=+:
""")
    